@@ -3,7 +3,8 @@ package WebService::OpenSky::Moose;
 # ABSTRACT: MooseX::Extended::Custom for WebService::OpenSky
 
 use MooseX::Extended::Custom;
-our $VERSION = '0.3';
+use PerlX::Maybe 'provided';
+our $VERSION = '0.4';
 
 # If $^P is true, we're running under the debugger.
 #
@@ -11,24 +12,10 @@ our $VERSION = '0.3';
 # because the way the debugger works with B::Hooks::AtRuntime will cause
 # the class to be made immutable before the we apply everything we need. This
 # causes the code to die.
-sub import {
-    my ( $class, %args ) = @_;
-
-    # we exclude strictconstructor because, otherwise, the delayed param trick
-    # for OpenSky::API::Core will fail.
-    my @excludes = 'StrictConstructor';
-    if ($^P) {
-        state $warned;
-        unless ($warned) {
-            $warned++;
-            say STDERR "Running under the debugger. Excluding make_immutable\n";
-        }
-        push @excludes => 'immutable';
-    }
-    push @excludes => 'immutable' unless $^P;
+sub import ( $class, %args ) {
     MooseX::Extended::Custom->create(
-        includes => [ 'method', 'try' ],
-        excludes => \@excludes,
+        includes => 'method',
+        provided $^P, excludes => 'immutable',
         %args    # you need this to allow customization of your customization
     );
 }
@@ -45,7 +32,7 @@ WebService::OpenSky::Moose - MooseX::Extended::Custom for WebService::OpenSky
 
 =head1 VERSION
 
-version 0.3
+version 0.4
 
 =head1 DESCRIPTION
 
